cobbler.settings.migrations package
===================================

Submodules
----------

cobbler.settings.migrations.V2\_8\_5 module
-------------------------------------------

.. automodule:: cobbler.settings.migrations.V2_8_5
   :members:
   :undoc-members:
   :show-inheritance:

cobbler.settings.migrations.V3\_0\_0 module
-------------------------------------------

.. automodule:: cobbler.settings.migrations.V3_0_0
   :members:
   :undoc-members:
   :show-inheritance:

cobbler.settings.migrations.V3\_0\_1 module
-------------------------------------------

.. automodule:: cobbler.settings.migrations.V3_0_1
   :members:
   :undoc-members:
   :show-inheritance:

cobbler.settings.migrations.V3\_1\_0 module
-------------------------------------------

.. automodule:: cobbler.settings.migrations.V3_1_0
   :members:
   :undoc-members:
   :show-inheritance:

cobbler.settings.migrations.V3\_1\_1 module
-------------------------------------------

.. automodule:: cobbler.settings.migrations.V3_1_1
   :members:
   :undoc-members:
   :show-inheritance:

cobbler.settings.migrations.V3\_1\_2 module
-------------------------------------------

.. automodule:: cobbler.settings.migrations.V3_1_2
   :members:
   :undoc-members:
   :show-inheritance:

cobbler.settings.migrations.V3\_2\_0 module
-------------------------------------------

.. automodule:: cobbler.settings.migrations.V3_2_0
   :members:
   :undoc-members:
   :show-inheritance:

cobbler.settings.migrations.V3\_2\_1 module
-------------------------------------------

.. automodule:: cobbler.settings.migrations.V3_2_1
   :members:
   :undoc-members:
   :show-inheritance:

cobbler.settings.migrations.V3\_3\_0 module
-------------------------------------------

.. automodule:: cobbler.settings.migrations.V3_3_0
   :members:
   :undoc-members:
   :show-inheritance:

cobbler.settings.migrations.helper module
-----------------------------------------

.. automodule:: cobbler.settings.migrations.helper
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: cobbler.settings.migrations
   :members:
   :undoc-members:
   :show-inheritance:
